"""Grill - gRPC interface logging library."""

import warnings

from .clients import (
    DummyLoggerClient,
    LoggerClient,
    LogProperties,
    LogProperty,
    LogReferences,
    Properties as _Properties,  # noqa: F401
    References as _References,  # noqa: F401
    SearchLoggerHistoryAsyncClient,
    SearchLoggerHistoryClient,
    User,
    get_logger_client,
)
from .logger import LogEntry, Logger

__version__ = "2.4.0"
__all__ = [
    "DummyLoggerClient",
    "LogEntry",
    "Logger",
    "LoggerClient",
    "LogProperty",
    "LogProperties",
    "LogReferences",
    "SearchLoggerHistoryAsyncClient",
    "SearchLoggerHistoryClient",
    "User",
    "get_logger_client",
]


_replaced = {
    "Properties": "LogProperties",
    "References": "LogReferences",
}


def __getattr__(name):  # type: ignore [no-untyped-def]
    if name in _replaced:  # pragma: nocover
        warnings.warn(f"'{name}' has been replaced with '{_replaced[name]}'", DeprecationWarning, stacklevel=2)
        return globals()[f"_{name}"]
    raise AttributeError(f"module '{__name__!r}' has no attribute '{name!r}'")
